# 999 seal

**Description:** Attempts to seal (finalize) the session's results. The "seal" stage requests authorization to finalize and (optionally) apply the changes.

**Usage:** `999 seal [--apply --authority-token <token>]`

Without `--apply`, this command performs a dry-run law check to see if sealing is allowed. With `--apply` and a valid authority token, it will request arifOS to approve the session. Only if arifOS returns a "SEAL" verdict and the token is provided will the session be marked sealed. Otherwise, the seal is refused (resulting in a HOLD or SABAR outcome).
